@@ -52,6 +52,19 @@ class MopekaAdvertisement(object):
     _raw_mfg_data: bytes
 
     def __init__(self, data: bytes):
+        """ init from ble advertising data
+
+        preamble: 3
+        Access Address: 6
+        GAP Packet: N
+        GAP Packet[1]: N
+        GAP_Packet[2]: N
+
+        GAP Packet:
+            length: 1 (length of packet not including the length byte)
+            type: 1
+            Payload: N
+        """
 
         self.rssi = rssi_from_byte(data[-1])
         self.mac = BDAddress(data[3:9])
@@ -191,7 +204,7 @@ class MopekaAdvertisement(object):
     @property
     def TankLevelInInches(self) -> float:
         """ The tank level/depth in inches"""
-        return self.TankLevelInMM / 25.4
+        return round(self.TankLevelInMM / 25.4, 2)
 
     def __str__(self) -> str:
         return ("MopekaAdvertisement -  " +
